<?php
/**
 * Graphics Designer: Customizer
 *
 * @subpackage Graphics Designer
 * @since 1.0
 */

use WPTRT\Customize\Section\Graphics_Designer_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Graphics_Designer_Button::class );

	$manager->add_section(
		new Graphics_Designer_Button( $manager, 'graphics_designer_pro', [
			'title' => __( 'Graphics Designer Pro', 'graphics-designer' ),
			'priority' => 0,
			'button_text' => __( 'Go Pro', 'graphics-designer' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/product/graphics-design-wordpress-theme', 'graphics-designer')
		] )
	);

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'graphics-designer-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);

	wp_enqueue_style(
		'graphics-designer-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function graphics_designer_customize_register( $wp_customize ) {

	$wp_customize->add_setting('graphics_designer_logo_padding',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('graphics_designer_logo_padding',array(
		'label' => __('Logo Margin','graphics-designer'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('graphics_designer_logo_top_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'graphics_designer_sanitize_float'
	));
	$wp_customize->add_control('graphics_designer_logo_top_padding',array(
		'type' => 'number',
		'description' => __('Top','graphics-designer'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('graphics_designer_logo_bottom_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'graphics_designer_sanitize_float'
	));
	$wp_customize->add_control('graphics_designer_logo_bottom_padding',array(
		'type' => 'number',
		'description' => __('Bottom','graphics-designer'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('graphics_designer_logo_left_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'graphics_designer_sanitize_float'
	));
	$wp_customize->add_control('graphics_designer_logo_left_padding',array(
		'type' => 'number',
		'description' => __('Left','graphics-designer'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('graphics_designer_logo_right_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'graphics_designer_sanitize_float'
 	));
 	$wp_customize->add_control('graphics_designer_logo_right_padding',array(
		'type' => 'number',
		'description' => __('Right','graphics-designer'),
		'section' => 'title_tagline',
    ));

	$wp_customize->add_setting('graphics_designer_show_site_title',array(
		'default' => true,
		'sanitize_callback'	=> 'graphics_designer_sanitize_checkbox'
	));
	$wp_customize->add_control('graphics_designer_show_site_title',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Title','graphics-designer'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('graphics_designer_show_tagline',array(
		'default' => true,
		'sanitize_callback'	=> 'graphics_designer_sanitize_checkbox'
	));
	$wp_customize->add_control('graphics_designer_show_tagline',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Tagline','graphics-designer'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_panel( 'graphics_designer_panel_id', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Settings', 'graphics-designer' ),
		'description' => __( 'Description of what this panel does.', 'graphics-designer' ),
	) );

	$wp_customize->add_section( 'graphics_designer_theme_options_section', array(
    	'title'      => __( 'General Settings', 'graphics-designer' ),
		'priority'   => 30,
		'panel' => 'graphics_designer_panel_id'
	) );

	$wp_customize->add_setting('graphics_designer_theme_options',array(
		'default' => 'One Column',
		'sanitize_callback' => 'graphics_designer_sanitize_choices'
	));
	$wp_customize->add_control('graphics_designer_theme_options',array(
		'type' => 'select',
		'label' => __('Blog Page Sidebar Layout','graphics-designer'),
		'section' => 'graphics_designer_theme_options_section',
		'choices' => array(
		   'Left Sidebar' => __('Left Sidebar','graphics-designer'),
		   'Right Sidebar' => __('Right Sidebar','graphics-designer'),
		   'One Column' => __('One Column','graphics-designer'),
		   'Grid Layout' => __('Grid Layout','graphics-designer')
		),
	));

	$wp_customize->add_setting('graphics_designer_single_post_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'graphics_designer_sanitize_choices'
	));
	$wp_customize->add_control('graphics_designer_single_post_sidebar',array(
        'type' => 'select',
        'label' => __('Single Post Sidebar Layout','graphics-designer'),
        'section' => 'graphics_designer_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','graphics-designer'),
            'Right Sidebar' => __('Right Sidebar','graphics-designer'),
            'One Column' => __('One Column','graphics-designer')
        ),
	));

	$wp_customize->add_setting('graphics_designer_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'graphics_designer_sanitize_choices'
	));
	$wp_customize->add_control('graphics_designer_page_sidebar',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','graphics-designer'),
        'section' => 'graphics_designer_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','graphics-designer'),
            'Right Sidebar' => __('Right Sidebar','graphics-designer'),
            'One Column' => __('One Column','graphics-designer')
        ),
	));

	$wp_customize->add_setting('graphics_designer_archive_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'graphics_designer_sanitize_choices'
	));
	$wp_customize->add_control('graphics_designer_archive_page_sidebar',array(
        'type' => 'select',
        'label' => __('Archive & Search Page Sidebar Layout','graphics-designer'),
        'section' => 'graphics_designer_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','graphics-designer'),
            'Right Sidebar' => __('Right Sidebar','graphics-designer'),
            'One Column' => __('One Column','graphics-designer'),
            'Grid Layout' => __('Grid Layout','graphics-designer')
        ),
	));

	//Header
	$wp_customize->add_section( 'graphics_designer_header' , array(
    	'title'    => __( 'Header Section', 'graphics-designer' ),
		'priority' => null,
		'panel' => 'graphics_designer_panel_id'
	) );


	$wp_customize->add_setting('graphics_designer_phone_number',array(
    	'default' => '',
    	'sanitize_callback'	=> 'graphics_designer_sanitize_phone_number'
	));
	$wp_customize->add_control('graphics_designer_phone_number',array(
	   	'type' => 'url',
	   	'label' => __('Add Phone Number','graphics-designer'),
	   	'section' => 'graphics_designer_header',
	));


	$wp_customize->add_setting('graphics_designer_email',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('graphics_designer_email',array(
	   	'type' => 'text',
	   	'label' => __('Add Mail','graphics-designer'),
	   	'section' => 'graphics_designer_header',
	));

	$wp_customize->add_setting('graphics_designer_facebook_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('graphics_designer_facebook_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Facebook URL','graphics-designer'),
	   	'section' => 'graphics_designer_header',
	));

	$wp_customize->add_setting('graphics_designer_twitter_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('graphics_designer_twitter_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Twitter URL','graphics-designer'),
	   	'section' => 'graphics_designer_header',
	));

	$wp_customize->add_setting('graphics_designer_instagram_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('graphics_designer_instagram_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Instagram URL','graphics-designer'),
	   	'section' => 'graphics_designer_header',
	));

	$wp_customize->add_setting('graphics_designer_pinterest_url',array(
    	'default' => '',
    	'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('graphics_designer_pinterest_url',array(
	   	'type' => 'url',
	   	'label' => __('Add Pinterest URL','graphics-designer'),
	   	'section' => 'graphics_designer_header',
	));


	//home page slider
	$wp_customize->add_section( 'graphics_designer_slider_section' , array(
    	'title'    => __( 'Slider Settings', 'graphics-designer' ),
		'priority' => null,
		'panel' => 'graphics_designer_panel_id'
	) );

	$wp_customize->add_setting('graphics_designer_slider_hide_show',array(
    	'default' => false,
    	'sanitize_callback'	=> 'graphics_designer_sanitize_checkbox'
	));
	$wp_customize->add_control('graphics_designer_slider_hide_show',array(
	   	'type' => 'checkbox',
	   	'label' => __('Show / Hide Slider','graphics-designer'),
	   	'section' => 'graphics_designer_slider_section',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'graphics_designer_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'graphics_designer_sanitize_dropdown_pages'
		));
		$wp_customize->add_control( 'graphics_designer_slider' . $count, array(
			'label' => __('Select Slider Image Page', 'graphics-designer' ),
			'section' => 'graphics_designer_slider_section',
			'type' => 'dropdown-pages'
		));
	}

	//Service Section
	$wp_customize->add_section('graphics_designer_service_section',array(
		'title'	=> __('Service Section','graphics-designer'),
		'description'=> __('This section will appear below the features section.','graphics-designer'),
		'panel' => 'graphics_designer_panel_id',
	));

    $wp_customize->add_setting('graphics_designer_section_title',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('graphics_designer_section_title',array(
		'label'	=> __('Section Title','graphics-designer'),
		'section' => 'graphics_designer_service_section',
		'type' => 'text'
	));

	$wp_customize->add_setting('graphics_designer_section_subtitle',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('graphics_designer_section_subtitle',array(
		'label'	=> __('Section Sub Title','graphics-designer'),
		'section' => 'graphics_designer_service_section',
		'type' => 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst1[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst1[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('graphics_designer_service_category_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'graphics_designer_sanitize_choices',
	));
	$wp_customize->add_control('graphics_designer_service_category_setting',array(
		'type' => 'select',
		'choices' => $cat_pst1,
		'label' => __('Select Category to display Post','graphics-designer'),
		'section' => 'graphics_designer_service_section',
	));

	//Footer
    $wp_customize->add_section( 'graphics_designer_footer', array(
    	'title'  => __( 'Footer Text', 'graphics-designer' ),
		'priority' => null,
		'panel' => 'graphics_designer_panel_id'
	) );

	$wp_customize->add_setting('graphics_designer_show_back_totop',array(
       'default' => true,
       'sanitize_callback'	=> 'graphics_designer_sanitize_checkbox'
    ));
    $wp_customize->add_control('graphics_designer_show_back_totop',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Back to Top','graphics-designer'),
       'section' => 'graphics_designer_footer'
    ));

    $wp_customize->add_setting('graphics_designer_footer_copy',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('graphics_designer_footer_copy',array(
		'label'	=> __('Footer Text','graphics-designer'),
		'section' => 'graphics_designer_footer',
		'setting' => 'graphics_designer_footer_copy',
		'type' => 'text'
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'graphics_designer_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'graphics_designer_customize_partial_blogdescription',
	) );
}
add_action( 'customize_register', 'graphics_designer_customize_register' );

function graphics_designer_customize_partial_blogname() {
	bloginfo( 'name' );
}

function graphics_designer_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

function graphics_designer_customizer_script() {
   wp_enqueue_style( 'font-awesome-1', esc_url(get_template_directory_uri()).'/assets/css/fontawesome-all.css');
}
add_action( 'customize_controls_enqueue_scripts', 'graphics_designer_customizer_script' );